@@ -1,8 +1,9 @@
 package Hypatia;
 {
-  $Hypatia::VERSION = '0.01.1';
+  $Hypatia::VERSION = '0.01';
 }
 use Moose;
+use Hypatia::Config;
 use Hypatia::Columns;
 use Class::Load qw(load_class);
 use Data::Dumper;
@@ -116,7 +117,7 @@ Hypatia - A Data Visualization API
 
 =head1 VERSION
 
-version 0.01.1
+version 0.01
 
 =head1 SYNOPSIS
 
